/**
 * 
 */
package de.mpc.prolic.model;

import java.util.ArrayList;

/**
 * Representation of a protein.
 * @author Michael Kohl
 */
public class Protein extends Biomolecule {
	
	/*******************************************************************************
	 * Members
	 ******************************************************************************/										
	private String proteinName; 			//The name of this protein, i.e. the accession number
	private String geneName;				//The name of the gene, that codes for the protein sequence of this protein. Not each biomolecule 
											//has a relationship to a specific gene. Metabolites are such an example. 
	private ArrayList<Peptide> peptides;	//The peptides that are identified for this protein within a Proteomics experiment. 
	/*******************************************************************************
	 * Constructors
	 ******************************************************************************/	

	/**
	 * Empty constructor
	 */
	public Protein() {
		init();
	}

	/**
	 * The default constructor for generating instances of Protein
	 * @param sequence_
	 */
	public Protein(String sequence_, String origin_) {
		super(sequence_, origin_);
		init();
	}
	
	/**
	 * Necessary initializations of a protein instance (= no protein without peptides)
	 */
	private void init(){
		peptides = new  ArrayList<Peptide>();
	}
	
	/**
	 * Adding a peptide to the protein.
	 */
	public void addPeptide(Peptide peptide_){
		this.peptides.add(peptide_);
	}

	
	/*******************************************************************************
	 * Setter and Getter
	 ******************************************************************************/
	public String getProteinName(){
		return proteinName;
	}
	
	public void setProteinName(String proteinName_){
		proteinName = proteinName_;
	}
	
	public String getGeneName(){
		return geneName;
	}
	
	public void setGeneName(String geneName_){
		geneName = geneName_;
	}
	
	public ArrayList<Peptide> getPeptides(){
		return peptides;
	}
	
	public void setPeptides(ArrayList<Peptide> peptides_){
		peptides = peptides_;
	}
}
